# Generated by Django 3.0.7 on 2020-07-21 08:50

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Email',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('subject', models.CharField(max_length=255)),
                ('mail_to', models.EmailField(max_length=254)),
                ('cc', models.TextField(null=True)),
                ('bcc', models.TextField(null=True)),
                ('body', models.TextField()),
                ('html_body', models.TextField()),
                ('attachment', models.FileField(null=True, upload_to='invoices/%Y/%m/%d')),
                ('start_send_at', models.DateTimeField(blank=True, null=True)),
                ('sent_at', models.DateTimeField(blank=True, null=True)),
            ],
        ),
    ]
