# Generated by Django 4.0.2 on 2022-02-24 16:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mailing', '0002_auto_20200722_1834'),
    ]

    operations = [
        migrations.AddField(
            model_name='email',
            name='email_from',
            field=models.EmailField(default='nonexistent@example.com', max_length=254, verbose_name='Mail From'),
            preserve_default=False,
        ),
    ]
