# Generated by Django 3.0.7 on 2020-07-22 18:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mailing', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='email',
            name='attachment',
            field=models.FileField(null=True, upload_to='invoices/%Y/%m/%d', verbose_name='Attachment'),
        ),
        migrations.AlterField(
            model_name='email',
            name='bcc',
            field=models.TextField(null=True, verbose_name='bcc'),
        ),
        migrations.AlterField(
            model_name='email',
            name='body',
            field=models.TextField(verbose_name='Body'),
        ),
        migrations.AlterField(
            model_name='email',
            name='cc',
            field=models.TextField(null=True, verbose_name='cc'),
        ),
        migrations.AlterField(
            model_name='email',
            name='html_body',
            field=models.TextField(verbose_name='HTML Body'),
        ),
        migrations.AlterField(
            model_name='email',
            name='mail_to',
            field=models.EmailField(max_length=254, verbose_name='Mail To'),
        ),
        migrations.AlterField(
            model_name='email',
            name='sent_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Sent At'),
        ),
        migrations.AlterField(
            model_name='email',
            name='start_send_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Start Send At'),
        ),
        migrations.AlterField(
            model_name='email',
            name='subject',
            field=models.CharField(max_length=255, verbose_name='Subject'),
        ),
    ]
